{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Perform sequence quality control for Illumina data using the Deblur workflow with a 16S reference as a positive filter",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "The demultiplexed sequences to be denoised",
                    "inputBinding": {
                        "prefix": "--i-demultiplexed-seqs"
                    },
                    "id": "#deblur-denoise-16S.cwl/demultiplexed_seqs"
                },
                {
                    "type": "string",
                    "label": "The resulting feature sequences filename",
                    "inputBinding": {
                        "prefix": "--o-representative-sequences"
                    },
                    "default": "rep-seqs.qza",
                    "id": "#deblur-denoise-16S.cwl/representative_sequences_filename"
                },
                {
                    "type": "string",
                    "label": "The resulting per-sample stats filename",
                    "inputBinding": {
                        "prefix": "--o-stats"
                    },
                    "default": "stats.qza",
                    "id": "#deblur-denoise-16S.cwl/stats_filename"
                },
                {
                    "type": "string",
                    "label": "The resulting denoised feature table filename",
                    "inputBinding": {
                        "prefix": "--o-table"
                    },
                    "default": "table.qza",
                    "id": "#deblur-denoise-16S.cwl/table_filename"
                },
                {
                    "type": "int",
                    "label": "Sequence trim length, specify -1 to disable trimming",
                    "inputBinding": {
                        "prefix": "--p-trim-length"
                    },
                    "id": "#deblur-denoise-16S.cwl/trim_length"
                }
            ],
            "baseCommand": [
                "qiime",
                "deblur",
                "denoise-16S",
                "--p-sample-stats"
            ],
            "id": "#deblur-denoise-16S.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.representative_sequences_filename)"
                    },
                    "id": "#deblur-denoise-16S.cwl/representative_sequences"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.stats_filename)"
                    },
                    "id": "#deblur-denoise-16S.cwl/stats"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.table_filename)"
                    },
                    "id": "#deblur-denoise-16S.cwl/table"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Display Deblur statistics per sample",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "The resulting visualization filename",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "default": "deblur-stats.qzv",
                    "id": "#deblur-visualize-stats.cwl/deblur_stats_filename"
                },
                {
                    "type": "File",
                    "label": "Summary statistics of the Deblur proces",
                    "inputBinding": {
                        "prefix": "--i-deblur-stats"
                    },
                    "id": "#deblur-visualize-stats.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.deblur_stats_filename)"
                    },
                    "id": "#deblur-visualize-stats.cwl/deblur_stats"
                }
            ],
            "baseCommand": [
                "qiime",
                "deblur",
                "visualize-stats"
            ],
            "id": "#deblur-visualize-stats.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Generate a tabular view of metadata",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "metadata file or artifact viewable as metadata",
                    "inputBinding": {
                        "prefix": "--m-input-file"
                    },
                    "id": "#metadata-tabulate.cwl/input_file"
                },
                {
                    "type": "string",
                    "label": "filename for the resulting visualization file",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "id": "#metadata-tabulate.cwl/visualization_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.visualization_filename)"
                    },
                    "id": "#metadata-tabulate.cwl/visualization_artifact"
                }
            ],
            "baseCommand": [
                "qiime",
                "metadata",
                "tabulate"
            ],
            "id": "#metadata-tabulate.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "label": "qiime2 Deblur detect/correct sequence data",
            "doc": "Option 2: Deblur from https://docs.qiime2.org/2018.4/tutorials/moving-pictures/",
            "inputs": [
                {
                    "type": "string",
                    "default": "demux-filter-stats.qzv",
                    "id": "#main/demux_filter_visualization_filename"
                },
                {
                    "type": "File",
                    "id": "#main/demux_sequences_artifact"
                },
                {
                    "type": "int",
                    "id": "#main/trim_length"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/deblur_metadata_tabulate/visualization_artifact",
                    "id": "#main/demux_filter_stats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/deblur_quality_filter/filter_stats",
                    "id": "#main/filter_stats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/deblur_quality_filter/filtered_sequences",
                    "id": "#main/filtered_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#main/deblur_denoise/representative_sequences",
                    "id": "#main/rep_seqs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/deblur_denoise/stats",
                    "id": "#main/stats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/deblur_visualize/deblur_stats",
                    "id": "#main/stats_visualization"
                },
                {
                    "type": "File",
                    "outputSource": "#main/deblur_denoise/table",
                    "id": "#main/table"
                }
            ],
            "steps": [
                {
                    "run": "#deblur-denoise-16S.cwl",
                    "in": [
                        {
                            "source": "#main/demux_sequences_artifact",
                            "id": "#main/deblur_denoise/demultiplexed_seqs"
                        },
                        {
                            "source": "#main/trim_length",
                            "id": "#main/deblur_denoise/trim_length"
                        }
                    ],
                    "out": [
                        "#main/deblur_denoise/representative_sequences",
                        "#main/deblur_denoise/table",
                        "#main/deblur_denoise/stats"
                    ],
                    "id": "#main/deblur_denoise"
                },
                {
                    "run": "#metadata-tabulate.cwl",
                    "in": [
                        {
                            "source": "#main/deblur_quality_filter/filter_stats",
                            "id": "#main/deblur_metadata_tabulate/input_file"
                        },
                        {
                            "source": "#main/demux_filter_visualization_filename",
                            "id": "#main/deblur_metadata_tabulate/visualization_filename"
                        }
                    ],
                    "out": [
                        "#main/deblur_metadata_tabulate/visualization_artifact"
                    ],
                    "id": "#main/deblur_metadata_tabulate"
                },
                {
                    "run": "#quality-filter-q-score.cwl",
                    "in": [
                        {
                            "source": "#main/demux_sequences_artifact",
                            "id": "#main/deblur_quality_filter/demux"
                        }
                    ],
                    "out": [
                        "#main/deblur_quality_filter/filtered_sequences",
                        "#main/deblur_quality_filter/filter_stats"
                    ],
                    "id": "#main/deblur_quality_filter"
                },
                {
                    "run": "#deblur-visualize-stats.cwl",
                    "in": [
                        {
                            "source": "#main/deblur_denoise/stats",
                            "id": "#main/deblur_visualize/input_file"
                        }
                    ],
                    "out": [
                        "#main/deblur_visualize/deblur_stats"
                    ],
                    "id": "#main/deblur_visualize"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Filter sequences based on quality scores and the presence of ambiguous base calls",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "The demultiplexed sequence data to be quality filtered",
                    "inputBinding": {
                        "prefix": "--i-demux"
                    },
                    "id": "#quality-filter-q-score.cwl/demux"
                },
                {
                    "type": "string",
                    "doc": "Summary statistics of the filtering process filename",
                    "inputBinding": {
                        "prefix": "--o-filter-stats"
                    },
                    "default": "demux-filter-stats.qza",
                    "id": "#quality-filter-q-score.cwl/filter_stats_filename"
                },
                {
                    "type": "string",
                    "doc": "The resulting quality-filtered sequences filename",
                    "inputBinding": {
                        "prefix": "--o-filtered-sequences"
                    },
                    "default": "demux-filtered.qza",
                    "id": "#quality-filter-q-score.cwl/filtered_sequences_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.filter_stats_filename)"
                    },
                    "id": "#quality-filter-q-score.cwl/filter_stats"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.filtered_sequences_filename)"
                    },
                    "id": "#quality-filter-q-score.cwl/filtered_sequences"
                }
            ],
            "baseCommand": [
                "qiime",
                "quality-filter",
                "q-score"
            ],
            "id": "#quality-filter-q-score.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
